summaryrefslogtreecommitdiff
path: root/src/rmd_cache_audio.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/rmd_cache_audio.h')
-rw-r--r--src/rmd_cache_audio.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/rmd_cache_audio.h b/src/rmd_cache_audio.h
index 1ba3221..377bc0a 100644
--- a/src/rmd_cache_audio.h
+++ b/src/rmd_cache_audio.h
@@ -31,12 +31,12 @@
/**
* Sound caching thread. Simply writes the pcm buffers on disk
*
* \param pdata ProgData struct containing all program data
*
*/
-void *rmdCacheSoundBuffer(ProgData *pdata);
+void *rmdCacheAudioBuffer(ProgData *pdata);
#endif
© All Rights Reserved
@@ -31,12 +31,12 @@
/**
-* Sound caching thread. Simply writes the pcm buffers on disk
+* Audio caching thread. Simply writes the pcm buffers on disk
*
* \param pdata ProgData struct containing all program data